# API Reference

This section is a reference guide for the _NNG_ programming interfaces.
It is meant to serve as a reference, rather than as a tutorial.

The material here is organized by major areas of functionality.

Note that unless indicated otherwise, consumers of these interfaces must
include the `nng/nng.h` header file like so:

```c
#include <nng/nng.h>
```

## Sections

- [Initialization](init.md)
- [Messages](msg.md)
- [Sockets](sock.md)
- [Contexts](ctx.md)
- [Pipes](pipe.md)
- [Memory](memory.md)
- [Time](time.md)
- [URLs](url.md)
- [Synchronization](synch.md)
- [Threads](thr.md)
- [Logging](logging.md)
- [Statistics](stats.md)
- [HTTP](http.md)
- [Miscellaneous](misc.md)
- [Errors](errors.md)
- [ID Map](id_map.md)
- [Command Options](cmd_opts.md)
